SoMeWeTa
========

SoMeWeTa (short for Social Media and Web Tagger) is a part-of-speech
tagger that supports domain adaptation and that can incorporate
external sources of information such as Brown clusters and lexica. It
is based on the averaged structured perceptron and uses beam search
and an early update strategy. It is possible to train and evaluate the
tagger on partially annotated data.

SoMeWeTa achieves state-of-the-art results on the German web and
social media texts from the `EmpiriST 2015 shared task
<https://sites.google.com/site/empirist2015/>`_ on automatic
linguistic annotation of computer-mediated communication / social
media. Therefore, SoMeWeTa is particularly well-suited to tag all
kinds of written German discourse, for example chats, forums, wiki
talk pages, tweets, blog comments, social networks, SMS and WhatsApp
dialogues.

In addition, we also provide models trained on German, English and
French newspaper texts. For all three languages, SoMeWeTa achieves
highly competitive results close to the current state of the art.

More detailed documentation is available `here
<https://github.com/tsproisl/SoMeWeTa>`_.
